View source: R/traditional_indexes.R
| traditional_indexes | R Documentation |
Computes a list of indexes proposed in the literature to measure the seat-to-vote deviations from proportionality. (See the malapportionment_index function for the Samuels and Snyder’s index).
traditional_indexes(votes, seats)
votes |
A vector of length p (where p the number of parties) with the votes gained by each party in the election.
When blank or null votes are included in |
seats |
A vector of length p (where p the number of parties) with components in the same order as |
A data.frame of order 10x3 with the Rae, Loosemore-Handy, Gallagher, Monroe, Sainte-Lague, Entropy, Taagepera-Laasko-v, Taagepera-Laasko-s, Taagapera-Shugart, Pessini-Gini and Pavia-Gini indexes.
The Entropy index (EI) only considers parties gaining seats.
Alberto Penades, alberto.penades@gmail.com
Jose M. Pavia, pavia@uv.es
Riera, P and Penades, A Indices of Disproportionality. Elgar Encyclopedia of Political Representation (Eds. A Freire, A Pedrazzani & H Schmit). Cheltenham: Edgar Elgar Publishing.
Taagepera, R and Shugart, MS (1991) Seats and Votes: The Effects and Determinants of Electoral Systems. New Haven: Yale University Press.
votes.ex <- c(Party1 = 6310391, Party2 = 5371866, Party3 = 1709890,
Party4 = 1504771, Party5 = 323444)
seats.ex <- c(Party1 = 165, Party2 = 118, Party3 = 20,
Party4 = 16, Party5 = 0)
example <- traditional_indexes(votes.ex, seats.ex)
example
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.